pub struct SingleSumSMA<T, D = T> {
window: VecDeque<T>,
window_size: usize,
sum: T,
_div: PhantomData<D>,
}Expand description
Basic implementation of Simple Moving Average (SMA).
The maximum window size is bound by 2^32 - 1.
Useful mainly for integer types, as it does accumulate floating point error with each sample.
Requires O(N) of memory and O(1) for average computation, N being window size.
The divisor argument D is used only for such types T that do not implement From<u32> (such as Duration,…).
Fields
window: VecDeque<T>window_size: usizesum: T_div: PhantomData<D>Implementations
Sourceimpl<T, D> SingleSumSMA<T, D>
impl<T, D> SingleSumSMA<T, D>
Sourcepub fn new(window_size: usize) -> Self
pub fn new(window_size: usize) -> Self
Creates an empty SMA instance with the given window size. The maximum window size is u32::MAX and must be greater than 1.
Sourcepub fn new_with_samples<I>(window_size: usize, initial_samples: I) -> Selfwhere
I: IntoIterator<Item = T>,
pub fn new_with_samples<I>(window_size: usize, initial_samples: I) -> Selfwhere
I: IntoIterator<Item = T>,
Creates SMA instance given window size and some initial samples.